@@ -1,7 +1,7 @@
 import json
 
-from semantha_sdk.rest.RestClient import RestClient
-from semantha_sdk.api.SemanthaAPI import SemanthaAPI
+from semantha_sdk.rest.rest_client import RestClient
+from semantha_sdk.api.semantha_api import SemanthaAPI
 
 
 def login(server_url: str, key: str = None, key_file: str = None) -> SemanthaAPI:
@@ -25,6 +25,6 @@ def login(server_url: str, key: str = None, key_file: str = None) -> SemanthaAPI
         raise ValueError("You need to supply an API key to login, either directly or via a file.")
 
     # check whether API key is valid or not
-    __s.current_user.get_user_data()
+    __s.current_user.get()
 
     return __s
