@@ -1,8 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-
-from marshmallow import fields
+from typing import Optional
 
 from semantha_sdk.model.paragraph import Paragraph
 from semantha_sdk.model.semantha_entity import SemanthaModelEntity
@@ -10,14 +9,9 @@ from semantha_sdk.model.semantha_entity import SemanthaModelEntity
 
 @dataclass(frozen=True)
 class PageContent(SemanthaModelEntity):
-    paragraphs: list[Paragraph]
-
-
-
+    paragraphs: Optional[list[Paragraph]]
 
 
 @dataclass(frozen=True)
 class Page(SemanthaModelEntity):
     contents: list[PageContent]
-
-
