@@ -9,8 +9,9 @@ class PageContentSchema(SemanthaSchema, with_entity(PageContent)):
     paragraphs = fields.Nested(
         nested=ParagraphSchema,
         data_key="paragraphs",
-        required=True,
-        many=True
+        required=False,
+        many=True,
+        load_default=None
     )
 
 
