@@ -22,8 +22,9 @@ class ParagraphSchema(SemanthaSchema, with_entity(Paragraph)):
     sentences = fields.Nested(
         nested=SentenceSchema,
         data_key="sentences",
-        required=True,
-        many=True
+        required=False,
+        many=True,
+        load_default=None
     )
     document_name = fields.Str(
         data_key="documentName",
